@@ -12,21 +12,26 @@ fn main() {
     let cc;
     let mut cflags;
 
+    #[cfg(not(feature = "riot-rs"))]
+    let compile_commands_json = "RIOT_COMPILE_COMMANDS_JSON";
+    #[cfg(feature = "riot-rs")]
+    let compile_commands_json = "DEP_RIOT_BUILD_COMPILE_COMMANDS_JSON";
+
     println!("cargo:rerun-if-env-changed=RIOT_CC");
     println!("cargo:rerun-if-env-changed=RIOT_CFLAGS");
-    println!("cargo:rerun-if-env-changed=RIOT_COMPILE_COMMANDS_JSON");
+    println!("cargo:rerun-if-env-changed={}", &compile_commands_json);
 
-    if let Ok(commands_json) = env::var("RIOT_COMPILE_COMMANDS_JSON") {
+    if let Ok(commands_json) = env::var(compile_commands_json) {
         println!("cargo:rerun-if-changed={}", commands_json);
-        let commands_file =
-            std::fs::File::open(commands_json).expect("Failed to open RIOT_COMPILE_COMMANDS_JSON");
+        let commands_file = std::fs::File::open(&commands_json)
+            .expect(&format!("Failed to open {}", &commands_json));
 
         #[derive(Debug, serde::Deserialize)]
         struct Entry {
             arguments: Vec<String>,
         }
         let parsed: Vec<Entry> = serde_json::from_reader(commands_file)
-            .expect("Failed to parse RIOT_COMPILE_COMMANDS_JSON");
+            .expect(&format!("Failed to parse {}", &compile_commands_json));
 
         // We need to find a consensus list -- otherwise single modules like stdio_uart that
         // defines anything odd for its own purpose can throw things off. (It's not like the actual
@@ -95,9 +100,24 @@ fn main() {
             .to_string();
         cflags = shlex::join(consensus_cflag_groups.unwrap().iter().flatten().map(|s| *s));
 
-        println!("cargo:rerun-if-env-changed=RIOT_USEMODULE");
-        let usemodule = env::var("RIOT_USEMODULE")
-            .expect("RIOT_USEMODULE is required when RIOT_COMPILE_COMMANDS_JSON is given");
+        let usemodule = {
+            #[cfg(not(feature = "riot-rs"))]
+            {
+                println!("cargo:rerun-if-env-changed=RIOT_USEMODULE");
+                env::var("RIOT_USEMODULE").expect(&format!(
+                    "RIOT_USEMODULE is required when {} is given",
+                    &compile_commands_json,
+                ))
+            }
+            #[cfg(feature = "riot-rs")]
+            {
+                println!("cargo:rerun-if-env-changed=DEP_RIOT_BUILD_DIR");
+                let riot_builddir =
+                    env::var("DEP_RIOT_BUILD_DIR").expect("DEP_RIOT_BUILD_DIR unset?");
+                get_riot_var(&riot_builddir, "USEMODULE")
+            }
+        };
+
         for m in usemodule.split(" ") {
             // Hack around https://github.com/RIOT-OS/RIOT/pull/16129#issuecomment-805810090
             write!(
@@ -329,13 +349,16 @@ fn main() {
     // C2Rust still generates old-style ASM -- workaround for https://github.com/immunant/c2rust/issues/306
     rustcode = rustcode.replace(" asm!(", " llvm_asm!(");
 
-    // There's only one `pub type` usually, and that breaks use on stable, and src/inline.rs has a
-    // workaround for that
-    rustcode = rustcode.replace("\n    pub type __locale_t;", "");
-    rustcode = rustcode.replace("\n    pub type _IO_wide_data;", "");
-    rustcode = rustcode.replace("\n    pub type _IO_codecvt;", "");
-    rustcode = rustcode.replace("\n    pub type _IO_marker;", "");
-    rustcode = rustcode.replace("\n    pub type __lock;", "");
+    println!("cargo:rerun-if-env-changed=CARGO_FEATURE_KEEP_EXTERN_TYPES");
+    if env::var("CARGO_FEATURE_KEEP_EXTERN_TYPES").is_err() {
+        // There's only one `pub type` usually, and that breaks use on stable, and src/inline.rs has a
+        // workaround for that
+        rustcode = rustcode.replace("\n    pub type __locale_t;", "");
+        rustcode = rustcode.replace("\n    pub type _IO_wide_data;", "");
+        rustcode = rustcode.replace("\n    pub type _IO_codecvt;", "");
+        rustcode = rustcode.replace("\n    pub type _IO_marker;", "");
+        rustcode = rustcode.replace("\n    pub type __lock;", "");
+    }
 
     // This only matches when c2rust is built to even export body-less functions
     rustcode = rustcode.replace("    #[no_mangle]\n    fn ", "    #[no_mangle]\n    pub fn ");
@@ -421,6 +444,11 @@ fn main() {
     // macro_.
     //
     // Some functions are also in because they're innocuous enough.
+    //
+    // If (eg. on some platform but not on others) any function here is not an inline function,
+    // that does not hurt; the entry doesn't do anything on these then. (But it is especially
+    // valuable, as it ensures that on the *other* platforms it's still available with the same
+    // Rust name).
     let mut toplevel_from_inline: Vec<String> = [
         "bluetil_ad_add_flags",
         "coap_get_code_raw",
@@ -451,7 +479,7 @@ fn main() {
     }
     let toplevel_from_inline: Vec<String> = toplevel_from_inline
         .drain(..)
-        .filter(|s: &String| rustcode.contains(s))
+        .filter(|s: &String| rustcode.contains(&format!(" {}(", s)))
         .collect();
     let toplevel_from_inline_filename = out_path.join("toplevel_from_inline.rs");
     std::fs::File::create(toplevel_from_inline_filename)
@@ -492,6 +520,8 @@ fn main() {
     let markers = [
         // See https://github.com/RIOT-OS/RIOT/pull/17569, available after 2022.01
         ("pub const UNIT_T:", "phydat_unit_t"),
+        // See https://github.com/RIOT-OS/RIOT/pull/17660, available after 2022.01
+        ("vfs_iterate_mount_dirs", "vfs_iterate_mount_dirs"),
     ];
     for (needle, name) in markers {
         if bindgen_output.contains(needle) {
@@ -499,3 +529,17 @@ fn main() {
         }
     }
 }
+
+#[cfg(feature = "riot-rs")]
+fn get_riot_var(riot_builddir: &str, var: &str) -> String {
+    let output = std::process::Command::new("sh")
+        .arg("-c")
+        .arg(format!(
+            "{} make --no-print-directory -C {} TOOLCHAIN=llvm info-debug-variable-{}",
+            "WARNING_EXTERNAL_MODULE_DIRS=0", riot_builddir, var
+        ))
+        .output()
+        .unwrap()
+        .stdout;
+    String::from_utf8_lossy(output.as_slice()).trim_end().into()
+}
